@@ -2,6 +2,7 @@
  *
  * Copyright © 2001 Ximian, Inc.
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,9 +50,15 @@
 
 #include "mate-settings-profile.h"
 #include "msd-a11y-keyboard-manager.h"
+#ifdef HAVE_LIBATSPI
+# include "msd-a11y-keyboard-atspi.h"
+#endif
 #include "msd-a11y-preferences-dialog.h"
 
 #define CONFIG_SCHEMA "org.mate.accessibility-keyboard"
+#ifdef HAVE_LIBATSPI
+# define KEY_CAPSLOCK_BEEP_ENABLED "capslock-beep-enable"
+#endif
 #define NOTIFICATION_TIMEOUT 30
 
 struct MsdA11yKeyboardManagerPrivate
@@ -64,6 +71,9 @@ struct MsdA11yKeyboardManagerPrivate
         GtkWidget *preferences_dialog;
         GtkStatusIcon *status_icon;
         XkbDescRec *original_xkb_desc;
+#ifdef HAVE_LIBATSPI
+        MsdA11yKeyboardAtspi *capslock_beep;
+#endif
 
         GSettings  *settings;
 
@@ -72,6 +82,14 @@ struct MsdA11yKeyboardManagerPrivate
 #endif /* HAVE_LIBNOTIFY */
 };
 
+/* Keep in sync with the org.mate.accessibility-keyboard.TogglekeysBackend
+ * enum from the org.mate.accessibility-keyboard schema. */
+typedef enum
+{
+        TOGGLEKEYS_BACKEND_XKB,
+        TOGGLEKEYS_BACKEND_INTERNAL,
+} TogglekeysBackend;
+
 static void     msd_a11y_keyboard_manager_finalize (GObject *object);
 static void     msd_a11y_keyboard_manager_ensure_status_icon (MsdA11yKeyboardManager *manager);
 static void     set_server_from_settings (MsdA11yKeyboardManager *manager);
@@ -80,12 +98,13 @@ G_DEFINE_TYPE_WITH_PRIVATE (MsdA11yKeyboardManager, msd_a11y_keyboard_manager, G
 
 static gpointer manager_object = NULL;
 
-#undef DEBUG_ACCESSIBILITY
-#ifdef DEBUG_ACCESSIBILITY
-#define d(str)          g_debug (str)
-#else
-#define d(str)          do { } while (0)
-#endif
+static gboolean
+togglekeys_backend_enabled (MsdA11yKeyboardManager *manager,
+                            TogglekeysBackend       backend)
+{
+        return (g_settings_get_boolean (manager->priv->settings, "togglekeys-enable") &&
+                g_settings_get_enum (manager->priv->settings, "togglekeys-backend") == (gint) backend);
+}
 
 static GdkFilterReturn
 devicepresence_filter (GdkXEvent *xevent,
@@ -184,8 +203,7 @@ get_xkb_desc_rec (MsdA11yKeyboardManager *manager)
         }
         gdk_x11_display_error_trap_pop_ignored (display);
 
-        g_return_val_if_fail (desc != NULL, NULL);
-        g_return_val_if_fail (desc->ctrls != NULL, NULL);
+        g_return_val_if_fail (desc != NULL && desc->ctrls != NULL, NULL);
         g_return_val_if_fail (status == Success, NULL);
 
         return desc;
@@ -209,11 +227,11 @@ set_int (GSettings      *settings,
 {
         int pre_val = g_settings_get_int (settings, key);
         g_settings_set_int (settings, key, val);
-#ifdef DEBUG_ACCESSIBILITY
+#ifdef MATE_ENABLE_DEBUG
         if (val != pre_val) {
                 g_warning ("%s changed", key);
         }
-#endif
+#endif /* MATE_ENABLE_DEBUG */
         return val != pre_val;
 }
 
@@ -226,12 +244,12 @@ set_bool (GSettings      *settings,
         gboolean pre_val = g_settings_get_boolean (settings, key);
 
         g_settings_set_boolean (settings, key, bval ? TRUE : FALSE);
-#ifdef DEBUG_ACCESSIBILITY
+#ifdef MATE_ENABLE_DEBUG
         if (bval != pre_val) {
-                d ("%s changed", key);
+                g_debug ("%s changed", key);
                 return TRUE;
         }
-#endif
+#endif /* MATE_ENABLE_DEBUG */
         return (bval != pre_val);
 }
 
@@ -367,7 +385,7 @@ set_server_from_settings (MsdA11yKeyboardManager *manager)
         }
 
         /* toggle keys */
-        desc->ctrls->ax_options = set_clear (g_settings_get_boolean (manager->priv->settings, "togglekeys-enable"),
+        desc->ctrls->ax_options = set_clear (togglekeys_backend_enabled (manager, TOGGLEKEYS_BACKEND_XKB),
                                              desc->ctrls->ax_options,
                                              XkbAccessXFeedbackMask | XkbAX_IndicatorFBMask);
 
@@ -414,7 +432,7 @@ ax_response_callback (MsdA11yKeyboardManager *manager,
         case GTK_RESPONSE_CANCEL:
 
                 /* we're reverting, so we invert sense of 'enabled' flag */
-                d ("cancelling AccessX request");
+                g_debug ("cancelling AccessX request");
                 if (revert_controls_mask == XkbStickyKeysMask) {
                         g_settings_set_boolean (manager->priv->settings,
                                                "stickykeys-enable",
@@ -495,7 +513,7 @@ maybe_show_status_icon (MsdA11yKeyboardManager *manager)
 
 #ifdef HAVE_LIBNOTIFY
 static void
-on_notification_closed (NotifyNotification     *notification,
+on_notification_closed (NotifyNotification     *notification G_GNUC_UNUSED,
                         MsdA11yKeyboardManager *manager)
 {
         g_object_unref (manager->priv->notification);
@@ -918,9 +936,11 @@ set_settings_from_server (MsdA11yKeyboardManager *manager)
                              "stickykeys-modifier-beep",
                              desc->ctrls->ax_options & XkbAX_StickyKeysFBMask);
 
-        changed |= set_bool (settings,
-                             "togglekeys-enable",
-                             desc->ctrls->ax_options & XkbAX_IndicatorFBMask);
+        if (g_settings_get_enum (manager->priv->settings, "togglekeys-backend") == TOGGLEKEYS_BACKEND_XKB) {
+                changed |= set_bool (settings,
+                                     "togglekeys-enable",
+                                     desc->ctrls->ax_options & XkbAX_IndicatorFBMask);
+        }
 
         if (!changed && stickykeys_changed ^ slowkeys_changed) {
                 /*
@@ -955,6 +975,56 @@ set_settings_from_server (MsdA11yKeyboardManager *manager)
         g_object_unref (settings);
 }
 
+typedef struct {
+        GdkDisplay *display;
+        gint count;
+} BeepSequenceData;
+
+static gboolean
+on_beep_dequence_timeout (gpointer user_data)
+{
+        BeepSequenceData *data = user_data;
+
+        gdk_display_beep (data->display);
+        data->count--;
+
+        return data->count > 0;
+}
+
+static void
+beep_sequence (MsdA11yKeyboardManager  *manager,
+               GdkDisplay              *display,
+               gint                     count,
+               gint                     delay)
+{
+        g_return_if_fail (MSD_IS_A11Y_KEYBOARD_MANAGER (manager));
+
+        if (count < 1)
+                return;
+
+        if (! display)
+                display = gdk_display_get_default ();
+
+        gdk_display_beep (display);
+        if (count > 1) {
+                BeepSequenceData *data = g_malloc (sizeof *data);
+
+                /* don't allow more than 8 beeps total, nor a delay outside
+                 * the range 50ms-5s: anything outside this is not very
+                 * reasonable and is more likely to be a broken setting,
+                 * and we don't want to be beeping forever. */
+                g_warn_if_fail (count <= 8);
+                g_warn_if_fail (delay >= 50 && delay <= 5000);
+
+                data->display = display;
+                data->count = MIN (8, count) - 1;
+                delay = CLAMP (delay, 50, 5000);
+
+                g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) delay,
+                                    on_beep_dequence_timeout, data, g_free);
+        }
+}
+
 static GdkFilterReturn
 cb_xkb_event_filter (GdkXEvent              *xevent,
                      GdkEvent               *ignored1,
@@ -965,32 +1035,60 @@ cb_xkb_event_filter (GdkXEvent              *xevent,
 
         if (xev->xany.type == (manager->priv->xkbEventBase + XkbEventCode) &&
             xkbEv->any.xkb_type == XkbControlsNotify) {
-                d ("XKB state changed");
+                g_debug ("XKB state changed");
                 set_settings_from_server (manager);
         } else if (xev->xany.type == (manager->priv->xkbEventBase + XkbEventCode) &&
                    xkbEv->any.xkb_type == XkbAccessXNotify) {
                 if (xkbEv->accessx.detail == XkbAXN_AXKWarning) {
-                        d ("About to turn on an AccessX feature from the keyboard!");
+                        g_debug ("About to turn on an AccessX feature from the keyboard!");
                         /*
                          * TODO: when XkbAXN_AXKWarnings start working, we need to
                          * invoke ax_keys_warning_dialog_run here instead of in
                          * set_settings_from_server().
                          */
                 }
+        } else if (xev->xany.type == (manager->priv->xkbEventBase + XkbEventCode) &&
+                   xkbEv->any.xkb_type == XkbIndicatorStateNotify &&
+                   togglekeys_backend_enabled (manager, TOGGLEKEYS_BACKEND_INTERNAL)) {
+                GdkDisplay *display = gdk_x11_lookup_xdisplay (xkbEv->any.display);
+                gint beep_count;
+                gint beep_delay;
+
+                if (xkbEv->indicators.state & xkbEv->indicators.changed) {
+                        beep_count = g_settings_get_int (manager->priv->settings, "togglekeys-enable-beep-count");
+                        beep_delay = g_settings_get_int (manager->priv->settings, "togglekeys-enable-beep-delay");
+                } else {
+                        beep_count = g_settings_get_int (manager->priv->settings, "togglekeys-disable-beep-count");
+                        beep_delay = g_settings_get_int (manager->priv->settings, "togglekeys-disable-beep-delay");
+                }
+                beep_sequence (manager, display, beep_count, beep_delay);
         }
 
         return GDK_FILTER_CONTINUE;
 }
 
 static void
-keyboard_callback (GSettings              *settings,
-                   gchar                  *key,
+keyboard_callback (GSettings              *settings G_GNUC_UNUSED,
+                   gchar                  *key G_GNUC_UNUSED,
                    MsdA11yKeyboardManager *manager)
 {
         set_server_from_settings (manager);
         maybe_show_status_icon (manager);
 }
 
+#ifdef HAVE_LIBATSPI
+static void
+capslock_beep_callback (GSettings              *settings,
+                        gchar                  *key G_GNUC_UNUSED,
+                        MsdA11yKeyboardManager *manager)
+{
+        if (g_settings_get_boolean (settings, KEY_CAPSLOCK_BEEP_ENABLED))
+                msd_a11y_keyboard_atspi_start (manager->priv->capslock_beep);
+        else
+                msd_a11y_keyboard_atspi_stop (manager->priv->capslock_beep);
+}
+#endif
+
 static gboolean
 start_a11y_keyboard_idle_cb (MsdA11yKeyboardManager *manager)
 {
@@ -999,10 +1097,19 @@ start_a11y_keyboard_idle_cb (MsdA11yKeyboardManager *manager)
         g_debug ("Starting a11y_keyboard manager");
         mate_settings_profile_start (NULL);
 
+        manager->priv->settings = g_settings_new (CONFIG_SCHEMA);
+
+#ifdef HAVE_LIBATSPI
+        manager->priv->capslock_beep = msd_a11y_keyboard_atspi_new ();
+        if (g_settings_get_boolean (manager->priv->settings, KEY_CAPSLOCK_BEEP_ENABLED))
+                msd_a11y_keyboard_atspi_start (manager->priv->capslock_beep);
+        g_signal_connect (manager->priv->settings, "changed::"KEY_CAPSLOCK_BEEP_ENABLED,
+                          G_CALLBACK (capslock_beep_callback), manager);
+#endif
+
         if (!xkb_enabled (manager))
                 goto out;
 
-        manager->priv->settings = g_settings_new (CONFIG_SCHEMA);
         g_signal_connect (manager->priv->settings, "changed", G_CALLBACK (keyboard_callback), manager);
 
         set_devicepresence_handler (manager);
@@ -1012,9 +1119,10 @@ start_a11y_keyboard_idle_cb (MsdA11yKeyboardManager *manager)
         manager->priv->original_xkb_desc = get_xkb_desc_rec (manager);
 
         event_mask = XkbControlsNotifyMask;
-#ifdef DEBUG_ACCESSIBILITY
+        event_mask |= XkbIndicatorStateNotifyMask;
+#ifdef MATE_ENABLE_DEBUG
         event_mask |= XkbAccessXNotifyMask; /* make default when AXN_AXKWarning works */
-#endif
+#endif /* MATE_ENABLE_DEBUG */
 
         /* be sure to init before starting to monitor the server */
         set_server_from_settings (manager);
@@ -1043,7 +1151,11 @@ msd_a11y_keyboard_manager_start (MsdA11yKeyboardManager *manager,
 {
         mate_settings_profile_start (NULL);
 
-        g_idle_add ((GSourceFunc) start_a11y_keyboard_idle_cb, manager);
+        /* give our initialization a lower priority over msd-keyoboard so it
+         * restores the numlock state before we might start monitoring it */
+        g_idle_add_full (G_PRIORITY_LOW,
+                         (GSourceFunc) start_a11y_keyboard_idle_cb, manager,
+                         NULL);
 
         mate_settings_profile_end (NULL);
 
@@ -1111,6 +1223,10 @@ msd_a11y_keyboard_manager_stop (MsdA11yKeyboardManager *manager)
 
         p->slowkeys_shortcut_val = FALSE;
         p->stickykeys_shortcut_val = FALSE;
+
+#ifdef HAVE_LIBATSPI
+        g_clear_object (&p->capslock_beep);
+#endif
 }
 
 static void
@@ -1123,7 +1239,7 @@ msd_a11y_keyboard_manager_class_init (MsdA11yKeyboardManagerClass *klass)
 
 static void
 on_preferences_dialog_response (GtkDialog              *dialog,
-                                int                     response,
+                                int                     response G_GNUC_UNUSED,
                                 MsdA11yKeyboardManager *manager)
 {
         g_signal_handlers_disconnect_by_func (dialog,
@@ -1135,7 +1251,7 @@ on_preferences_dialog_response (GtkDialog              *dialog,
 }
 
 static void
-on_status_icon_activate (GtkStatusIcon          *status_icon,
+on_status_icon_activate (GtkStatusIcon          *status_icon G_GNUC_UNUSED,
                          MsdA11yKeyboardManager *manager)
 {
         if (manager->priv->preferences_dialog == NULL) {
