@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,7 +55,7 @@ G_DEFINE_TYPE_WITH_PRIVATE (MsdA11ySettingsManager, msd_a11y_settings_manager, G
 static gpointer manager_object = NULL;
 
 static void
-apps_settings_changed (GSettings              *settings,
+apps_settings_changed (GSettings              *settings G_GNUC_UNUSED,
 		       const char             *key,
 		       MsdA11ySettingsManager *manager)
 {
