@@ -2,6 +2,7 @@
  * vim: set et sw=8 ts=8:
  *
  * Copyright (c) 2008, Novell, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Authors: Vincent Untz <vuntz@gnome.org>
  *
@@ -554,8 +555,8 @@ ldsm_is_hash_item_not_in_mounts (gpointer key,
 }
 
 static void
-ldsm_mounts_changed (GObject  *monitor,
-                     gpointer  data)
+ldsm_mounts_changed (GObject  *monitor G_GNUC_UNUSED,
+                     gpointer  data G_GNUC_UNUSED)
 {
         GList *mounts;
 
@@ -584,7 +585,7 @@ ldsm_is_hash_item_in_ignore_paths (gpointer key,
 }
 
 static void
-msd_ldsm_get_config ()
+msd_ldsm_get_config (void)
 {
         gchar **settings_list;
 
@@ -612,8 +613,7 @@ msd_ldsm_get_config ()
                                                 SETTINGS_MIN_NOTIFY_PERIOD);
 
         if (ignore_paths != NULL) {
-                g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
-                g_slist_free (ignore_paths);
+                g_slist_free_full (ignore_paths, g_free);
                 ignore_paths = NULL;
         }
 
@@ -636,9 +636,9 @@ msd_ldsm_get_config ()
 }
 
 static void
-msd_ldsm_update_config (GSettings *settings,
-                        gchar *key,
-                        gpointer user_data)
+msd_ldsm_update_config (GSettings *gsettings G_GNUC_UNUSED,
+                        gchar *key G_GNUC_UNUSED,
+                        gpointer user_data G_GNUC_UNUSED)
 {
         msd_ldsm_get_config ();
 }
@@ -696,8 +696,7 @@ msd_ldsm_clean (void)
         }
 
         if (ignore_paths) {
-                g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
-                g_slist_free (ignore_paths);
+                g_slist_free_full (ignore_paths, g_free);
         }
 }
 
