@@ -3,6 +3,7 @@
  * msd-ldsm-trash-empty.c
  * Copyright (C) Chris Coulson 2009 <chrisccoulson@googlemail.com>
  *	     (C) Ryan Lortie 2008
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * msd-ldsm-trash-empty.c is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -233,7 +234,7 @@ trash_empty_job (GIOSchedulerJob *job,
 /* Worker thread end */
 
 static void
-trash_empty_start ()
+trash_empty_start (void)
 {
         GtkWidget *vbox1, *vbox2, *hbox;
         GtkWidget *label1, *label3;
@@ -252,40 +253,24 @@ trash_empty_start ()
 
         label1 = gtk_label_new (NULL);
         gtk_label_set_line_wrap (GTK_LABEL (label1), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (label1), 0.0);
         gtk_label_set_yalign (GTK_LABEL (label1), 0.5);
-#else
-        gtk_misc_set_alignment (GTK_MISC (label1), 0.0, 0.5);
-#endif
 
         label3 = gtk_label_new (NULL);
         gtk_label_set_line_wrap (GTK_LABEL (label3), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (label3), 0.0);
         gtk_label_set_yalign (GTK_LABEL (label3), 0.5);
-#else
-        gtk_misc_set_alignment (GTK_MISC (label3), 0.0, 0.5);
-#endif
         gtk_widget_hide (label3);
 
         location_label = gtk_label_new (NULL);
         gtk_label_set_line_wrap (GTK_LABEL (location_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (location_label), 0.0);
         gtk_label_set_yalign (GTK_LABEL (location_label), 0.5);
-#else
-        gtk_misc_set_alignment (GTK_MISC (location_label), 0.0, 0.5);
-#endif
 
         file_label = gtk_label_new (NULL);
         gtk_label_set_line_wrap (GTK_LABEL (file_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (file_label), 0.0);
         gtk_label_set_yalign (GTK_LABEL (file_label), 0.5);
-#else
-        gtk_misc_set_alignment (GTK_MISC (file_label), 0.0, 0.5);
-#endif
 
         progressbar = gtk_progress_bar_new ();
         gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (progressbar), 0.1);
@@ -333,7 +318,7 @@ trash_empty_start ()
 static void
 trash_empty_confirmation_response (GtkDialog *dialog,
                                    gint       response_id,
-                                   gpointer   user_data)
+                                   gpointer   user_data G_GNUC_UNUSED)
 {
         if (response_id == GTK_RESPONSE_YES)
                 trash_empty_start ();
@@ -356,7 +341,7 @@ trash_empty_require_confirmation (void)
 }
 
 static void
-trash_empty_show_confirmation_dialog ()
+trash_empty_show_confirmation_dialog (void)
 {
         GtkWidget *button;
 
