@@ -2,6 +2,7 @@
  *
  * Copyright © 2001 Ximian, Inc.
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -201,8 +202,6 @@ apply_settings (GSettings          *settings,
         XKeyboardControl kbdcontrol;
         gboolean         repeat;
         gboolean         click;
-        int              rate;
-        int              delay;
         int              click_volume;
         int              bell_volume;
         int              bell_pitch;
@@ -215,8 +214,6 @@ apply_settings (GSettings          *settings,
 
         repeat        = g_settings_get_boolean  (settings, KEY_REPEAT);
         click         = g_settings_get_boolean  (settings, KEY_CLICK);
-        rate          = g_settings_get_int   (settings, KEY_RATE);
-        delay         = g_settings_get_int   (settings, KEY_DELAY);
         click_volume  = g_settings_get_int   (settings, KEY_CLICK_VOLUME);
         bell_pitch    = g_settings_get_int   (settings, KEY_BELL_PITCH);
         bell_duration = g_settings_get_int   (settings, KEY_BELL_DURATION);
@@ -233,8 +230,9 @@ apply_settings (GSettings          *settings,
                 XAutoRepeatOn (GDK_DISPLAY_XDISPLAY (display));
                 /* Use XKB in preference */
 #ifdef HAVE_X11_EXTENSIONS_XKB_H
-                rate_set = xkb_set_keyboard_autorepeat_rate (delay, rate);
-#endif
+                rate_set = xkb_set_keyboard_autorepeat_rate (g_settings_get_int (settings, KEY_DELAY),
+                                                             g_settings_get_int (settings, KEY_RATE));
+#endif /* HAVE_X11_EXTENSIONS_XKB_H */
                 if (!rate_set)
                         g_warning ("Neither XKeyboard not Xfree86's keyboard extensions are available,\n"
                                    "no way to support keyboard autorepeat rate settings");
