@@ -3,6 +3,7 @@
  * Copyright (C) 2001-2003 Bastien Nocera <hadess@hadess.net>
  * Copyright (C) 2006-2007 William Jon McCann <mccann@jhu.edu>
  * Copyright (C) 2014 Michal Ratajsky <michal.ratajsky@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -600,7 +601,6 @@ do_eject_action (MsdMediaKeysManager *manager)
                         continue;
                 if (score < SCORE_HAS_MEDIA) {
                         fav_drive = drive;
-                        score = SCORE_HAS_MEDIA;
                         break;
                 }
         }
@@ -666,7 +666,7 @@ update_dialog (MsdMediaKeysManager *manager,
                gboolean             is_mic)
 {
         if (muted)
-                volume = 0.0;
+                volume = 0;
 
         dialog_init (manager);
 
@@ -706,7 +706,8 @@ do_sound_action (MsdMediaKeysManager *manager,
         gboolean sound_changed = FALSE;
         guint    volume;
         guint    volume_min, volume_max;
-        guint    volume_step;
+        gint     volume_step;
+        guint    volume_step_scaled;
         guint    volume_last;
         MateMixerStreamControl *control;
 
@@ -727,12 +728,13 @@ do_sound_action (MsdMediaKeysManager *manager,
         volume_step = g_settings_get_int (manager->priv->settings, "volume-step");
         if (volume_step <= 0 || volume_step > 100) {
                 GVariant *variant = g_settings_get_default_value (manager->priv->settings, "volume-step");
-                volume_step = g_variant_get_int32 (variant);
+                gint32 volume_step_default = g_variant_get_int32 (variant);
+                volume_step = (gint) volume_step_default;
                 g_variant_unref (variant);
         }
 
         /* Scale the volume step size accordingly to the range used by the control */
-        volume_step = (volume_max - volume_min) * volume_step / 100;
+        volume_step_scaled = (volume_max - volume_min) * (guint) volume_step / 100;
 
         volume = volume_last =
                 mate_mixer_stream_control_get_volume (control);
@@ -745,11 +747,11 @@ do_sound_action (MsdMediaKeysManager *manager,
                 muted = !muted;
                 break;
         case VOLUME_DOWN_KEY:
-                if (volume <= (volume_min + volume_step)) {
+                if (volume <= (volume_min + volume_step_scaled)) {
                         volume = volume_min;
                         muted  = TRUE;
                 } else {
-                        volume -= volume_step;
+                        volume -= volume_step_scaled;
                         muted  = FALSE;
                 }
                 break;
@@ -757,9 +759,9 @@ do_sound_action (MsdMediaKeysManager *manager,
                 if (muted) {
                         muted = FALSE;
                         if (volume <= volume_min)
-                               volume = volume_min + volume_step;
+                               volume = volume_min + volume_step_scaled;
                 } else
-                        volume = CLAMP (volume + volume_step,
+                        volume = CLAMP (volume + volume_step_scaled,
                                         volume_min,
                                         volume_max);
                 break;
@@ -780,7 +782,7 @@ do_sound_action (MsdMediaKeysManager *manager,
         }
 
         update_dialog (manager,
-                       CLAMP (100 * volume / (volume_max - volume_min), 0, 100),
+                       MIN (100 * volume / (volume_max - volume_min), 100),
                        muted,
                        sound_changed,
                        quiet,
@@ -853,8 +855,8 @@ update_default_input (MsdMediaKeysManager *manager)
 }
 
 static void
-on_context_state_notify (MateMixerContext    *context,
-                         GParamSpec          *pspec,
+on_context_state_notify (MateMixerContext    *context G_GNUC_UNUSED,
+                         GParamSpec          *pspec G_GNUC_UNUSED,
                          MsdMediaKeysManager *manager)
 {
         update_default_output (manager);
@@ -862,23 +864,23 @@ on_context_state_notify (MateMixerContext    *context,
 }
 
 static void
-on_context_default_output_notify (MateMixerContext    *context,
-                                  GParamSpec          *pspec,
+on_context_default_output_notify (MateMixerContext    *context G_GNUC_UNUSED,
+                                  GParamSpec          *pspec G_GNUC_UNUSED,
                                   MsdMediaKeysManager *manager)
 {
         update_default_output (manager);
 }
 
 static void
-on_context_default_input_notify (MateMixerContext    *context,
-                                 GParamSpec          *pspec,
+on_context_default_input_notify (MateMixerContext    *context G_GNUC_UNUSED,
+                                 GParamSpec          *pspec G_GNUC_UNUSED,
                                  MsdMediaKeysManager *manager)
 {
         update_default_input (manager);
 }
 
 static void
-on_context_stream_removed (MateMixerContext    *context,
+on_context_stream_removed (MateMixerContext    *context G_GNUC_UNUSED,
                            const gchar         *name,
                            MsdMediaKeysManager *manager)
 {
@@ -1069,10 +1071,7 @@ msd_media_keys_manager_grab_media_player_keys (MsdMediaKeysManager *manager,
         MediaPlayer *media_player;
 
         if (time == GDK_CURRENT_TIME) {
-                GTimeVal tv;
-
-                g_get_current_time (&tv);
-                time = tv.tv_sec * 1000 + tv.tv_usec / 1000;
+                time = (guint32)(g_get_monotonic_time () / 1000);
         }
 
         iter = g_list_find_custom (manager->priv->media_players,
