@@ -1,6 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8; tab-width: 8 -*-
  *
  * Copyright (C) 2006 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -70,7 +71,7 @@ void                  msd_media_keys_window_set_mic_muted     (MsdMediaKeysWindo
 void                  msd_media_keys_window_set_volume_muted  (MsdMediaKeysWindow      *window,
                                                                gboolean                 muted);
 void                  msd_media_keys_window_set_volume_level  (MsdMediaKeysWindow      *window,
-                                                               int                      level);
+                                                               guint                    level);
 gboolean              msd_media_keys_window_is_valid          (MsdMediaKeysWindow      *window);
 
 #ifdef __cplusplus
