@@ -1,6 +1,7 @@
 /* msd-locate-pointer.c
  *
  * Copyright (C) 2008 Carlos Garnacho  <carlos@imendio.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -48,8 +49,6 @@ struct MsdLocatePointerData
   gdouble progress;
 };
 
-static MsdLocatePointerData *data = NULL;
-
 static void
 locate_pointer_paint (MsdLocatePointerData *data,
 		      cairo_t              *cr,
@@ -166,7 +165,7 @@ update_shape (MsdLocatePointerData *data)
 }
 
 static void
-timeline_frame_cb (MsdTimeline *timeline,
+timeline_frame_cb (MsdTimeline *timeline G_GNUC_UNUSED,
 		   gdouble      progress,
 		   gpointer     user_data)
 {
@@ -250,7 +249,7 @@ composited_changed (GdkScreen            *screen,
 }
 
 static void
-timeline_finished_cb (MsdTimeline *timeline,
+timeline_finished_cb (MsdTimeline *timeline G_GNUC_UNUSED,
 		      gpointer     user_data)
 {
   MsdLocatePointerData *data = (MsdLocatePointerData *) user_data;
@@ -266,7 +265,7 @@ timeline_finished_cb (MsdTimeline *timeline,
 }
 
 static void
-locate_pointer_unrealize_cb (GtkWidget            *widget,
+locate_pointer_unrealize_cb (GtkWidget            *widget G_GNUC_UNUSED,
                              MsdLocatePointerData *data)
 {
   if (data->window != NULL)
@@ -279,7 +278,7 @@ locate_pointer_unrealize_cb (GtkWidget            *widget,
 }
 
 static void
-locate_pointer_realize_cb (GtkWidget            *widget,
+locate_pointer_realize_cb (GtkWidget            *widget G_GNUC_UNUSED,
                            MsdLocatePointerData *data)
 {
   GdkDisplay *display;
@@ -321,7 +320,7 @@ locate_pointer_realize_cb (GtkWidget            *widget,
 }
 
 static gboolean
-locate_pointer_draw_cb (GtkWidget      *widget,
+locate_pointer_draw_cb (GtkWidget      *widget G_GNUC_UNUSED,
                         cairo_t        *cr,
                         gpointer        user_data)
 {
@@ -414,6 +413,7 @@ void
 msd_locate_pointer (GdkDisplay *display)
 {
   GdkScreen *screen = gdk_display_get_default_screen (display);
+  static MsdLocatePointerData *data = NULL;
 
   if (data == NULL)
     {
