@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1360,11 +1361,11 @@ set_natural_scroll_synaptics (XDeviceInfo *device_info,
         if (rc == Success && type == XA_INTEGER && format == 32 && nitems >= 2) {
                 ptr = (glong *) data;
                 if (natural_scroll) {
-                        ptr[0] = -abs(ptr[0]);
-                        ptr[1] = -abs(ptr[1]);
+                        ptr[0] = -labs(ptr[0]);
+                        ptr[1] = -labs(ptr[1]);
                 } else {
-                        ptr[0] = abs(ptr[0]);
-                        ptr[1] = abs(ptr[1]);
+                        ptr[0] = labs(ptr[0]);
+                        ptr[1] = labs(ptr[1]);
                 }
 
                 XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY (display), device, prop,
