@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2010 Red Hat, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -158,7 +159,7 @@ msd_smartcard_plugin_finalize (GObject *object)
 }
 
 static void
-smartcard_inserted_cb (MsdSmartcardManager *card_monitor,
+smartcard_inserted_cb (MsdSmartcardManager *card_monitor G_GNUC_UNUSED,
                        MsdSmartcard        *card,
                        MsdSmartcardPlugin  *plugin)
 {
@@ -229,7 +230,7 @@ process_smartcard_removal (MsdSmartcardPlugin *plugin)
 }
 
 static void
-smartcard_removed_cb (MsdSmartcardManager *card_monitor,
+smartcard_removed_cb (MsdSmartcardManager *card_monitor G_GNUC_UNUSED,
                       MsdSmartcard        *card,
                       MsdSmartcardPlugin  *plugin)
 {
